# Update from 3.6.0 to 3.8.3 is based on Fedora atlas package. See
# http://cvs.fedoraproject.org/viewvc/rpms/atlas/devel/atlas.spec?revision=1.23

%define enable_native_atlas 0

%define major		3
%define libatlas	libatlas
%define libname		%mklibname %{name} %{major}

Name:		atlas
Version:	3.10.3
Release:	%mkrel 14
Summary:	Automatically Tuned Linear Algebra Software
Group:		Sciences/Mathematics
License:	BSD
URL:		https://math-atlas.sourceforge.net/
Source0:	https://downloads.sourceforge.net/math-atlas/%{name}%{version}.tar.bz2
Source21:	https://math-atlas.sourceforge.net/errata.html
Source22:	https://math-atlas.sourceforge.net/faq.html
Source23:	https://www.cs.utsa.edu/~whaley/papers.html
Source30:	Makefile
Source31:	README.%{_real_vendor}
# Obtained by editing flags in the tarball from the sources with
# grep -r fpu | cut -d: -f 1 | sort -u | xargs sed -i -e 's,-mcpu=cortex-a8,-march=armv7-a,' -e 's,-mfpu=vfpv3,-mfpu=vfpv3-d16,' -e 's,-mtune=cortex-a8,,'
Source32:	ARMv732.tar.bz2

# Fedora patches:
# Properly pass -melf_* to the linker with -Wl, fixes FTBFS bug 817552
# https://sourceforge.net/tracker/?func=detail&atid=379484&aid=3555789&group_id=23725
Patch1:		atlas-melf.patch
Patch2:		atlas-throttling.patch
#credits Lukas Slebodnik
Patch3:		atlas-shared_libraries.patch

Patch4:		atlas-genparse.patch
Patch5:		atlas-3.10.3-fix-enum-OSTYPE.patch

# Unbundle LAPACK (BZ #1181369)
Patch6:		atlas.3.10.1-unbundle.patch
Patch7:		atlas-gcc10.patch
Patch15:	atlas-fgrep.patch

# Fix FTBFS with gfortran 10 (from debian)
Patch21:	missing-cflags.patch

#Covscan
Patch101:	atlas-getri.patch

# Gentoo patches for gcc-15
Patch110:	atlas-3.10.2-x32-support.patch
Patch111:	atlas-3.10.2-format-security.patch
Patch112:	atlas-3.10.3-fix-ancient-c.patch

Requires:	gcc-gfortran liblapack-devel
BuildRequires:	gcc-gfortran
BuildRequires:	liblapack-devel

%description
The ATLAS (Automatically Tuned Linear Algebra Software) project is an
ongoing research effort focusing on applying empirical techniques in
order to provide portable performance. At present, it provides C and
Fortran77 interfaces to a portably efficient BLAS implementation, as
well as a few routines from LAPACK.

The performance improvements in ATLAS are obtained largely via
compile-time optimizations and tend to be specific to a given hardware
configuration. In order to package ATLAS some compromises
are necessary so that good performance can be obtained on a variety
of hardware. This set of ATLAS binary packages is therefore not
necessarily optimal for any specific hardware configuration.  However,
the source package can be used to compile customized ATLAS packages;
see the documentation for information.

########################################################################

#--#####################################################################
%ifarch %{ix86}
%define types base

#----###################################################################
%package	-n %{libname}-base
Summary:	ATLAS libraries for SSE3 extensions (Pentium IV)
Group:		System/Libraries
%ifarch %{ix86}
Obsoletes:      %{libname}-sse2 < 3.10.3-5
Obsoletes:      %{libname}-sse3 < 3.10.3-5
%endif

%description	-n %{libname}-base
This package contains the ATLAS (Automatically Tuned Linear Algebra
Software) libraries compiled with base optimizations.
This is a generic binary package. Install the "%{name}" package
to build a version tuned for your computer.

%files		-n %{libname}-base
%dir %{_libdir}/atlas-base
%{_libdir}/atlas-base/*.so.*
%{_sysconfdir}/ld.so.conf.d/atlas-base.conf

#------#################################################################
%package	-n %{libatlas}-base-devel
Summary:	Development files for ATLAS SSE3 (Pentium IV)
Group:		Development/Other
Requires:	%{libname}-base = %{version}-%{release}
%ifarch %{ix86}
Obsoletes:      %{libname}-sse2-devel < 3.10.3-5
Obsoletes:      %{libname}-sse3-devel < 3.10.3-5
%endif
Provides:	%{libatlas}-devel = %{version}-%{release}

%description	-n %{libatlas}-base-devel
This package contains headers and development libraries of ATLAS
(Automatically Tuned Linear Algebra Software) compiled with base
optimizations.

%files		-n %{libatlas}-base-devel
%doc doc/*
%{_libdir}/atlas-base/*.so
%{_libdir}/atlas-base/*.a
%dir %{_includedir}/atlas
%{_includedir}/atlas/*.h

#--#####################################################################
%else

%define types	%{_arch}

#----###################################################################
%package	-n %{libname}-%{_arch}
Summary:	ATLAS libraries for %{_arch}
Group:		System/Libraries
Provides:	%{libatlas} = %{version}-%{release}

%description	-n %{libname}-%{_arch}
This package contains the ATLAS (Automatically Tuned Linear Algebra
Software) libraries compiled with %{_arch} optimizations.
This is a generic binary package. Install the "%{name}" package
to build a version tuned for your computer.

%files		-n %{libname}-%{_arch}
%dir %{_libdir}/atlas
%{_libdir}/atlas/*.so.*
%{_sysconfdir}/ld.so.conf.d/atlas.conf

#------#################################################################
%package	-n %{libatlas}-%{_arch}-devel
Summary:	Development files for ATLAS for %{_arch}
Group:		Development/Other
Requires:	%{libname}-%{_arch} = %{version}-%{release}
Provides:	%{libatlas}-devel = %{version}-%{release}

%description	-n %{libatlas}-%{_arch}-devel
This package contains headers and development libraries of ATLAS
(Automatically Tuned Linear Algebra Software) compiled with %{_arch}
optimizations.

%files		-n %{libatlas}-%{_arch}-devel
%doc doc/*
%{_libdir}/atlas/*.so
%{_libdir}/atlas/*.a
%dir %{_includedir}/atlas
%{_includedir}/atlas/*.h

%endif	# ix86

%ifarch %{arm}
%define threads_option -t 2
%global mode %{nil}
%ifarch armv7hl
%global armflags -DATL_ARM_HARDFP=1
%endif
%else
%global mode -b %{__isa_bits}
%if "%{?enable_native_atlas}" != "0"
%define threads_option -t 4
%else
%define threads_option -t 2
%endif
%endif

%bcond_without  base_arch
%if %{with base_arch}
%ifarch %{ix86}
  %define arch_option -A PIII -V 512
%endif
%ifarch x86_64
  %define arch_option -A HAMMER -V 896
%endif
%ifarch %{arm}
  %define arch_option -A ARMa7 -V 1
%endif
%ifarch aarch64
  %define arch_option -A ARM64a53 -V 1
%endif
%endif


%prep
%setup -q -n ATLAS
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p2
%patch -P 4 -p1
%patch -P 5 -p1
%patch -P 6 -p1
%patch -P 7 -p1
%patch -P 15 -p1

%patch -P 21 -p1

%patch -P 101 -p1

%patch -P 110 -p1
%patch -P 111 -p1
%patch -P 112 -p1

cp %{SOURCE21} %{SOURCE22} %{SOURCE23} doc

%ifarch %{arm}
%ifarch armv7hl
# This overrides flags to use hard abi on arm
cp -f %{SOURCE32} CONFIG/ARCHS/
# Set arm flags in atlcomp.txt
sed -i -e 's,-mfloat-abi=softfp,-mfloat-abi=hard,' CONFIG/src/atlcomp.txt
sed -i -e 's,-mcpu=cortex-a8,-march=armv7-a,' CONFIG/src/atlcomp.txt
sed -i -e 's,-mtune=cortex-a8,,' CONFIG/src/atlcomp.txt
sed -i -e 's,-mfpu=vfpv3,-mfpu=vfpv3-d16,' CONFIG/src/atlcomp.txt
%endif
# Some extra arm flags not needed
sed -i -e 's,-mfpu=vfpv3,,' tune/blas/gemm/CASES/*.flg
%endif

# Define common flags.
%global atlas_common -D_FORTIFY_SOURCE=2 -g -Wa,--noexecstack,--generate-missing-build-notes=yes -fpermissive -fstack-protector-strong -fstack-clash-protection -fPIC -Wl,-z,now

# Relax gcc-15.
sed -e 's|^cflags=.*|cflags="-g -w -std=gnu17 -fpermissive"|' -i configure

%build
for type in %{types}; do
    case $type in
	%{_arch})	libname=%{name}		;;
	*)		libname=%{name}-$type	;;
    esac
    mkdir -p %{_arch}_${type}
    pushd %{_arch}_${type}
	../configure %{mode} %{?threads_option} %{?arch_option} -v 2 -D c -DWALL \
	    -Fa alg '%{?armflags} %{atlas_common}'			\
	    --prefix=%{buildroot}%{_prefix}				\
	    --incdir=%{buildroot}%{_includedir}				\
	    --libdir=%{buildroot}%{_libdir}/${libname}

	if [ "$type" = "x86_64" ]; then
	        sed -i 's#ARCH =.*#ARCH = HAMMER64SSE3#' Make.inc
                sed -i 's#-DATL_AVX\w*##g' Make.inc
                sed -i 's#-mavx\w*#-msse3#g' Make.inc
                sed -i 's#-mfma\w*#-msse3#g' Make.inc
	fi
	sed -i 's#SLAPACKlib.*#SLAPACKlib = %{_libdir}/liblapack.so#' Make.inc
	%make_build -j1
	cd lib
	%make_build -j1 shared
	%make_build -j1 ptshared
    popd
done

%install
for type in %{types}; do
    case $type in
	%{_arch})	dirname=%{name}		;;
	*)		dirname=%{name}-$type	;;
    esac
    pushd %{_arch}_${type}
	make DESTDIR=%{buildroot} install || :
	mv %{buildroot}%{_includedir}/clapack.h %{buildroot}%{_includedir}/atlas
	mv %{buildroot}%{_includedir}/cblas.h %{buildroot}%{_includedir}/atlas
	mkdir -p %{buildroot}%{_libdir}/${dirname}
	cp -pr lib/*.so* %{buildroot}%{_libdir}/${dirname}/
	rm -f %{buildroot}%{_libdir}/${dirname}/*.a
	cp -pr lib/libcblas.a lib/libatlas.a lib/libf77blas.a lib/liblapack.a %{buildroot}%{_libdir}/${dirname}/
    popd
    mkdir -p %{buildroot}%{_sysconfdir}/ld.so.conf.d
    echo "%{_libdir}/${dirname}"				\
	> %{buildroot}%{_sysconfdir}/ld.so.conf.d/${dirname}.conf
done

mkdir -p %{buildroot}%{_libdir}/%{name}
mkdir -p %{buildroot}%{_usrsrc}
tar jxf %{SOURCE0} -C %{buildroot}%{_usrsrc}

for i in Makefile README.%{_real_vendor}; do
   for s in _arch _includedir _libdir _sysconfdir name; do
      sed -e 's!%%{_arch}!%{_arch}!g' \
          -e 's!%%{_docdir}!%{_docdir}!g' \
          -e 's!%%{_includedir}!%{_includedir}!g' \
          -e 's!%%{_libdir}!%{_libdir}!g' \
          -e 's!%%{mode}!%{mode}!g' \
          -e 's!%%{name}!%{name}!g' \
          -e 's!%%{_prefix}!%{_prefix}!g' \
          -e 's!%%{release}!%{release}!g' \
          -e 's!%%{_sysconfdir}!%{_sysconfdir}!g' \
          -e 's!%%{_usrsrc}!%{_usrsrc}!g' \
          -e 's!%%{version}!%{version}!g' \
      < %{_sourcedir}/$i > %{buildroot}%{_usrsrc}/ATLAS/$i
   done
done
echo %{buildroot}%{_usrsrc}/ATLAS/$i

%check
for type in %{types}; do
	pushd %{_arch}_${type}
	make check ptcheck
	popd
done

%post
echo "

  Please check %{_usrsrc}/ATLAS/README.%{_real_vendor} for build instructions.

"

%files
%dir %{_usrsrc}/ATLAS
%{_usrsrc}/ATLAS/*
%dir %{_includedir}/%{name}
%dir %{_libdir}/%{name}
%doc doc/*


%changelog
* Sun Jun 01 2025 daviddavid <daviddavid> 3.10.3-14.mga10
+ Revision: 2187780
- add some patches from gentoo and debian to fix build (thanks to Aurelian R)
+ pterjan <pterjan>
- Rebuild for patchN deprecation
+ danf <danf>
- Update links to https:

* Fri Mar 10 2023 daviddavid <daviddavid> 3.10.3-11.mga9
+ Revision: 1948561
- during the compilation, use grep -F instead of fgrep (from fedora)

* Thu Mar 17 2022 umeabot <umeabot> 3.10.3-10.mga9
+ Revision: 1797010
- Mageia 9 Mass Rebuild

* Thu Mar 03 2022 tv <tv> 3.10.3-9.mga9
+ Revision: 1788060
- Move the clapack.h and cblas.h to include/atlas directory, thus fixing
  conflict with lapack-3.10.0
- add some covscan related fixes
- kill another old unapplied patch
- kill old unapplied patch

* Sun Jun 28 2020 joequant <joequant> 3.10.3-8.mga8
+ Revision: 1599734
- install .a files

* Sun May 31 2020 tv <tv> 3.10.3-7.mga8
+ Revision: 1589131
- add provides: libatlas-devel to 32bit base-devel

* Thu May 21 2020 tv <tv> 3.10.3-6.mga8
+ Revision: 1586545
- Dropped sse2/sse3 subpackages for ix86

* Wed May 20 2020 tv <tv> 3.10.3-5.mga8
+ Revision: 1586369
- sync build flags
- Fix compatibility with gcc 10

* Wed Feb 12 2020 umeabot <umeabot> 3.10.3-4.mga8
+ Revision: 1510462
- Mageia 8 Mass Rebuild

* Fri Sep 21 2018 umeabot <umeabot> 3.10.3-3.mga7
+ Revision: 1295065
- Mageia 7 Mass Rebuild

* Tue Jul 31 2018 eatdirt <eatdirt> 3.10.3-2.mga7
+ Revision: 1246357
- Rebuild for new gfortran

* Tue Sep 19 2017 tv <tv> 3.10.3-1.mga7
+ Revision: 1155440
- new release

* Sat Sep 02 2017 tv <tv> 3.10.2-11.mga7
+ Revision: 1150569
- rebuild for new gcc-gfortran

* Mon Jul 31 2017 pterjan <pterjan> 3.10.2-10.mga7
+ Revision: 1133233
- Fix armv5tl build by not using hard abi config

* Tue Jun 27 2017 pterjan <pterjan> 3.10.2-9.mga6
+ Revision: 1108586
- Get the package to build for armv7 without neon
- Drop NEON config tarball, now included upstream and we don't use neon, and improve flags for armv7

* Sat Jun 17 2017 pterjan <pterjan> 3.10.2-8.mga6
+ Revision: 1107866
- Fix flags for armv5
- Do not enable neon on arm, our build machines do not support it, and only set hard float on v7

* Fri Jun 16 2017 pterjan <pterjan> 3.10.2-7.mga6
+ Revision: 1107807
- Improve arch flag overrides on x86_64 to prevent build failure on machines supporting avx2 (like autobuild)

* Thu Sep 22 2016 tv <tv> 3.10.2-6.mga6
+ Revision: 1055223
- set more flags for arm
- we use hard fp on armv7

* Wed Jul 20 2016 neoclust <neoclust> 3.10.2-5.mga6
+ Revision: 1042924
- Try to rebuild on arm
+ pterjan <pterjan>
- Define enable_native_atlas
- Use hardflot on armv7hl

* Wed May 25 2016 pterjan <pterjan> 3.10.2-4.mga6
+ Revision: 1018429
- Fix build on CPU >= Corei3

* Sun May 22 2016 shlomif <shlomif> 3.10.2-3.mga6
+ Revision: 1017521
- Hopefully fix the i586 build - 10x to david_david
+ tv <tv>
- drop sse package (uncompilable)
- mgarepo sync failed to add those :-(
- drop support for custom build (broken/simpler)
- do not inline big files in spec, package them as sources
 (as such, the Makefile we provide is now undependant of gcc version)
- add %%check
- configure like FC does
- sync description with FC
- sync patches with FC
- new release + sync patches with FC
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 3.8.4-6.mga5
+ Revision: 743315
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Sun Nov 17 2013 eatdirt <eatdirt> 3.8.4-4.mga4
+ Revision: 551659
- Removing detection of machine specific optimization (mga#11619)

* Sat Oct 19 2013 umeabot <umeabot> 3.8.4-3.mga4
+ Revision: 523186
- Mageia 4 Mass Rebuild

* Wed Mar 27 2013 mitya <mitya> 3.8.4-2.mga3
+ Revision: 405436
- Fix build for recent GCC, see RedHat Bug #817552
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ tv <tv>
- new release

* Tue May 10 2011 ahmad <ahmad> 3.8.3-7.mga1
+ Revision: 96864
- Drop old/unneeded scriptlets
- Drop buildroot declaration
- User the %%{_real_vendor} macro in the REAMDE.* file name
- imported package atlas


* Thu Dec 09 2010 Oden Eriksson <oeriksson@mandriva.com> 3.8.3-6mdv2011.0
+ Revision: 616629
- the mass rebuild of 2010.0 packages

* Thu Sep 03 2009 Lev Givon <lev@mandriva.org> 3.8.3-5mdv2010.0
+ Revision: 428962
- Incorporate update from rev 1.23 of Fedora spec file.

* Tue Apr 28 2009 Paulo Andrade <pcpa@mandriva.com.br> 3.8.3-4mdv2010.0
+ Revision: 369122
- Provide libatlas = %%{version}-%%{release} instead of libatlas%%{major} =
  %%{version}-%%{release}.

* Tue Mar 10 2009 Paulo Andrade <pcpa@mandriva.com.br> 3.8.3-3mdv2009.1
+ Revision: 353342
- Correct a major typo, where the libname major was "upgraded" instead of
  the package release.
- o Restore/reimplement enable_custom_atlas option, as an alternative to
  the "from sources" build, so that files are properly managed by rpm,
  but still built for a single computer.
  o Add explicit (untested) support for a generic ppc64 build, and assume
  any other arch is 32 bits.

* Mon Mar 09 2009 Paulo Andrade <pcpa@mandriva.com.br> 3.8.3-2mdv2009.1
+ Revision: 353292
+ rebuild (emptylog)

* Sat Mar 07 2009 Paulo Andrade <pcpa@mandriva.com.br> 3.8.3-1mdv2009.1
+ Revision: 350722
- Bump release and resubmit. ix86 build failed with message:
  EE: gcc: unknown error: PIC register 'bx' clobbered in 'asm'
  (Resubmit to check if same error will again, what could be a bug in
 how atlas build handle the ix86 build computer).
- Update to new upstream release 3.8.3.
  Atlas is a package that requires being compiled in the computer
  where it will be used. To achieve this, a "ready to build" setup
  is available in the main package, and generic precompiled library
  binaries are also available. The default ones are:
  o libatlas-sse2 for ix86
  This requires a Pentium IV class cpu ("modern" ix86 cpus support
  sse3, but Celeron and older Pentium IV class cpus support only sse2).
  o libatlas-x86_64 for x86_64
  Generic x86_64 build.
  Note that the build is dependent on the computer generating the
  packages, and the threaded/smp libraries will only be generated on
  builds on a multi core/cpu computer only.

* Thu Dec 18 2008 Lev Givon <lev@mandriva.org> 3.6.0-7mdv2009.1
+ Revision: 315405
- Rebuild.

* Wed Dec 10 2008 Lev Givon <lev@mandriva.org> 3.6.0-6mdv2009.1
+ Revision: 312567
- Obsolete libatlas3.0 packages.

* Mon Dec 01 2008 Lev Givon <lev@mandriva.org> 3.6.0-5mdv2009.1
+ Revision: 308686
- Build against latest lapack libs.
  Use latest diff file from Debian.

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers
    - no need for explicit Requires(post,postun) on ldconfig (rpm will add it automatically)

* Thu Mar 13 2008 Andreas Hasenack <andreas@mandriva.com> 3.6.0-4mdv2008.1
+ Revision: 187694
- rebuild for 2008.1

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Mon Dec 17 2007 Thierry Vignaud <tv@mandriva.org> 3.6.0-3mdv2008.1
+ Revision: 122240
- kill re-definition of %%buildroot on Pixel's request

  + Lev Givon <lev@mandriva.org>
    - import atlas


* Sun Sep 30 2007 Lev Givon <lev@mandriva.org> 3.6.0-3mdv2007.1
- Adapt Fedora spec file for Mandriva.
